Module jwks

Module jwks 

Structs

InjectionPayload
A single injection payload
Jwk
A single JSON Web Key
JwkSet
A JSON Web Key Set
JwksInjectionResult
Result of JWKS injection payload generation
KeyRotationResult
Result of testing a key in rotation
KeyVerifyResult
Result of verifying a token against a specific key
SpoofedJwks
Result of a spoofed JWKS generation

Functions

fetch_jwks
Fetch a JWKS from a remote URL
generate_jwks_injection_payloads
Generate JKU/X5U injection payloads with a real spoofed JWKS
generate_spoofed_jwks
Generate a spoofed JWKS with a new RSA key pair
jwk_rsa_to_pem
Convert a JWK RSA public key to PEM format
parse_jwks
Parse a JWKS from a JSON string
test_key_rotation
Test key rotation by verifying a token against multiple key files
verify_with_jwks
Verify a JWT token against all keys in a JWKS