prepare_hs256_verifier

Function prepare_hs256_verifier 

pub fn prepare_hs256_verifier(token: &str) -> Result<Hs256Verifier>
Build an Hs256Verifier from a JWT.

Returns Err when the token is malformed, not HS256, or has an empty signature. Callers should fall back to verify in that case.