pub fn start_progress_with_color(message: &str, color: &str) -> ProgressBarExpand description
Creates an animated spinner with a custom color to indicate ongoing operations
pub fn start_progress_with_color(message: &str, color: &str) -> ProgressBarCreates an animated spinner with a custom color to indicate ongoing operations