Structs
- Injection
Payload - A single injection payload
- Jwk
- A single JSON Web Key
- JwkSet
- A JSON Web Key Set
- Jwks
Injection Result - Result of JWKS injection payload generation
- KeyRotation
Result - Result of testing a key in rotation
- KeyVerify
Result - Result of verifying a token against a specific key
- Spoofed
Jwks - Result of a spoofed JWKS generation
Functions
- fetch_
jwks - Fetch a JWKS from a remote URL
- generate_
jwks_ injection_ payloads - Generate JKU/X5U injection payloads with a real spoofed JWKS
- generate_
spoofed_ jwks - Generate a spoofed JWKS with a new RSA key pair
- jwk_
rsa_ to_ pem - Convert a JWK RSA public key to PEM format
- parse_
jwks - Parse a JWKS from a JSON string
- test_
key_ rotation - Test key rotation by verifying a token against multiple key files
- verify_
with_ jwks - Verify a JWT token against all keys in a JWKS